@@ -15,6 +15,7 @@
 
 #include <boost/scoped_array.hpp>
 #include <boost/iostreams/filtering_stream.hpp>
+#include <boost/iostreams/filter/bytescounter.hpp>
 #include <boost/iostreams/filter/gzip.hpp>
 #include <boost/iostreams/device/nonclosable_file_descriptor.hpp>
 
@@ -36,10 +37,6 @@
 
 #include "CompressedMagic.hpp"
 
-// @drizzt rlog section grouping causes problem in this file
-#undef RLOG_SECTION
-#define RLOG_SECTION
-
 namespace io = boost::iostreams;
 namespace se = boost::serialization;
 
@@ -162,7 +159,7 @@ int Compress::truncate(const char *name, off_t size)
 		r = ::ftruncate(m_fd, FileHeader::MaxSize);
 		if (r == -1)
 			rWarning("Compress::truncate('%s', %ld) failed!",
-			          name, size);
+			          name, (long int) size);
 
 		m_RawFileSize = FileHeader::MaxSize;
 
@@ -292,31 +289,32 @@ off_t Compress::writeCompressed(LayerMap& lm, off_t offset, off_t coffset, const
 		//
 		// We have to do that until I find a way how to get length of
 		// the compressed block that is written by io::write()...
+		//
+		// OK, I now know how to get length of the compressed block,
+		// but I don't know anymore how to use it to avoid the truncation.
 
 		assert(bl->coffset == rawFileSize);
-		::ftruncate(fd, rawFileSize);
+		::ftruncate(fd, bl->coffset);
 
 		// Compress and write block to the file.
 
 		io::nonclosable_file_descriptor file(fd);
 		file.seek(bl->coffset, ios_base::beg);
+		io::bytescounter length;
 		{
 			io::filtering_ostream out;
 
 			bl->type.push(out);
+			out.push(boost::ref(length));
 			out.push(file);
 
 			io::write(out, buf, bl->length);
 
-			// Destroying the object 'out' causes all filters to
-			// flush.
+			// Destroying the object 'out' causes all filters to flush.
 		}
 
-		// Get length of the file to compute size of the written
-		// compressed block
-		//
-		coffset = file.seek(0, ios_base::end);
-		bl->clength = coffset - bl->coffset;
+		bl->clength = length.bytes();
+		coffset = bl->coffset + bl->clength;
 	}
 	catch (...)
 	{
@@ -639,6 +637,9 @@ off_t Compress::copy(int readFd, off_t writeOffset, int writeFd, LayerMap& write
 	while ((bytes = readCompressed(buf.get(), g_BufferedMemorySize, readOffset, readFd)) > 0)
 	{
 		writeOffset = writeCompressed(writeLm, readOffset, writeOffset, buf.get(), bytes, writeFd, writeOffset);
+		if (writeOffset == -1)
+			return -1;
+		assert (writeOffset == bytes);
 		readOffset += bytes;
 	}
 	return writeOffset;
@@ -651,7 +652,6 @@ off_t Compress::cleverCopy(int readFd, off_t writeOffset, int writeFd, LayerMap&
 
 	Block	 block;
 	off_t	 len;
-	char    *buf;
 
 	while (size > 0)
 	{
@@ -669,18 +669,20 @@ off_t Compress::cleverCopy(int readFd, off_t writeOffset, int writeFd, LayerMap&
 			// from it's de-compressed stream...
 
 			try {
+				boost::scoped_array<char> buf(new char[block.length]);
+
 				// Read old block (or part of it we need)...
 
-				off_t r;
-
-				buf = new char[block.length];
-				r = readBlock(readFd, block, size, len, offset, buf);
+				off_t r = readBlock(readFd, block, size, len, offset, buf.get());
 
 				// Write new block...
 
-				writeOffset = writeCompressed(writeLm, offset, writeOffset, buf, r, writeFd, writeOffset);
+				writeOffset = writeCompressed(writeLm, offset, writeOffset, buf.get(), r, writeFd, writeOffset);
+				if (writeOffset == -1)
+					return -1;
+
+				assert (r == writeOffset);
 
-				delete[] buf;
 				offset += r;
 				size -= r;
 			}
@@ -714,13 +716,13 @@ void Compress::DefragmentFast()
 	rDebug("%s", __PRETTY_FUNCTION__);
 
 	struct stat st;
-	struct timeval m_times[2];
+	struct timespec m_times[2];
 
 	::fstat(m_fd, &st);
 	m_times[0].tv_sec = st.st_atime;
-	m_times[0].tv_usec = 0;
+	m_times[0].tv_nsec = st.st_atim.tv_nsec;
 	m_times[1].tv_sec = st.st_mtime;
-	m_times[1].tv_usec = 0;
+	m_times[1].tv_nsec = st.st_mtim.tv_nsec;
 
 	// Prepare a temporary file.
 
@@ -737,23 +739,27 @@ void Compress::DefragmentFast()
 		return;
 	}
 
-	::fchmod(tmp_fd, st.st_mode);
-	::fchown(tmp_fd, st.st_uid, st.st_gid);
-	::futimes(tmp_fd, m_times);
-
 	// Reserve space for a FileHeader.
 
 	off_t tmp_offset = FileHeader::MaxSize;
 
 	// Temporary file prepared, now do the deframentation.
 
-	LayerMap			tmp_lm;
-	FileHeader			tmp_fh(m_fh);
+	LayerMap tmp_lm;
 
 	tmp_offset = cleverCopy(m_fd, tmp_offset, tmp_fd, tmp_lm);
 //	tmp_offset = copy(m_fd, tmp_offset, tmp_fd, tmp_lm);
 
-	::futimes(tmp_fd, m_times);
+	if (tmp_offset == -1)
+	{
+		::unlink(tmp_name);
+		::close(tmp_fd);
+		return;
+	}
+
+	::fchmod(tmp_fd, st.st_mode);
+	::fchown(tmp_fd, st.st_uid, st.st_gid);
+	::futimens(tmp_fd, m_times);
 
 	::close(m_fd);
 	m_fd = tmp_fd;
