@@ -2,8 +2,8 @@
 
 class FileRememberTimes
 {
-	int            m_fd;
-	struct timeval m_times[2];
+	int             m_fd;
+	struct timespec m_times[2];
 public:
 	FileRememberTimes(int fd);
 	~FileRememberTimes();
